==> tuia-advert-center-api-1.7.4-r-20181016.122044-2-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/AdvertBaseInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert;

import java.io.Serializable;
import java.util.List;

/**
 * Created by huangch on 2018/7/2 19:56
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertBaseInfoDto  implements Serializable {

    private static final long serialVersionUID = 5779929343630236723L;
    //广告ID
    private Long advertId;

    //广告名称
    private String advertName;

    //广告对应的AE名称
    private String aeName;

    //广告的行业标签，二级标签
    private String industryTag;

    //广告行业标签名称
    private String industryTagName;

    //是否为下载类广告，true-是、false-否
    private boolean isAppDownload;

    //广告的身上的标签，包括行业标签、属性标签和落地页标签
    private List<String> advertTags;

    public String getIndustryTag() {
        return industryTag;
    }

    public void setIndustryTag(String industryTag) {
        this.industryTag = industryTag;
    }

    public String getIndustryTagName() {
        return industryTagName;
    }

    public void setIndustryTagName(String industryTagName) {
        this.industryTagName = industryTagName;
    }

    public boolean isAppDownload() {
        return isAppDownload;
    }

    public void setAppDownload(boolean appDownload) {
        isAppDownload = appDownload;
    }

    public List<String> getAdvertTags() {
        return advertTags;
    }

    public void setAdvertTags(List<String> advertTags) {
        this.advertTags = advertTags;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }
}

==> tuia-advert-center-api-2.0.6-sources.jar: cn/com/duiba/tuia/core/api/dto/req/advert/AdvertBaseInfoDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.advert;

import java.io.Serializable;
import java.util.List;

/**
 * Created by huangch on 2018/7/2 19:56
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertBaseInfoDto  implements Serializable {

    private static final long serialVersionUID = 5779929343630236723L;
    //广告ID
    private Long advertId;

    //广告名称
    private String advertName;

    //广告对应的AE名称
    private String aeName;

    //AE邮箱，用于发送钉钉消息
    private String aeEmail;

    //广告的行业标签，二级标签
    private String industryTag;

    //广告行业标签名称
    private String industryTagName;

    //是否为下载类广告，true-是、false-否
    private boolean isAppDownload;

    //广告的身上的标签，包括行业标签、属性标签和落地页标签
    private List<String> advertTags;

    public String getIndustryTag() {
        return industryTag;
    }

    public void setIndustryTag(String industryTag) {
        this.industryTag = industryTag;
    }

    public String getAeEmail() {
        return aeEmail;
    }

    public void setAeEmail(String aeEmail) {
        this.aeEmail = aeEmail;
    }

    public String getIndustryTagName() {
        return industryTagName;
    }

    public void setIndustryTagName(String industryTagName) {
        this.industryTagName = industryTagName;
    }

    public boolean isAppDownload() {
        return isAppDownload;
    }

    public void setAppDownload(boolean appDownload) {
        isAppDownload = appDownload;
    }

    public List<String> getAdvertTags() {
        return advertTags;
    }

    public void setAdvertTags(List<String> advertTags) {
        this.advertTags = advertTags;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }
}
